==> jc-1.4.0.tar.gz: soot/jimple/parser/parser/ParserException.c <==
// public class soot.jimple.parser.parser.ParserException

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 84249dd9d0b5395d soot_jimple_parser_node_Token
// @dep_class 350479636530ccb1 soot_jimple_parser_parser_ParserException

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_jimple_parser_node_Token
// @dep_header soot_jimple_parser_parser_ParserException

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/jimple/parser/node/Token.h"
#include "soot/jimple/parser/parser/ParserException.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// soot.jimple.parser.node.Token token
static _jc_field _jc_soot_jimple_parser_parser_ParserException$field_info$token = {
	.name=		"token",
	.signature=	"Lsoot/jimple/parser/node/Token;",
	.class=		&_jc_soot_jimple_parser_parser_ParserException$type,
	.type=		&_jc_soot_jimple_parser_node_Token$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_soot_jimple_parser_parser_ParserException$object, refs[-1].soot_jimple_parser_parser_ParserException.token),
};

// Fields
static _jc_field *const _jc_soot_jimple_parser_parser_ParserException$fields[] = {
	&_jc_soot_jimple_parser_parser_ParserException$field_info$token
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(soot.jimple.parser.node.Token, java.lang.String)
//

static _jc_linenum _jc_soot_jimple_parser_parser_ParserException$linenum_table$_init$97df421f1d5b7fa0[];

static const unsigned char _jc_soot_jimple_parser_parser_ParserException$param_ptypes$_init$97df421f1d5b7fa0[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_soot_jimple_parser_parser_ParserException$param_types$_init$97df421f1d5b7fa0[] = {
	&_jc_soot_jimple_parser_node_Token$type,
	&_jc_java_lang_String$type
};

_jc_method _jc_soot_jimple_parser_parser_ParserException$method_info$_init$97df421f1d5b7fa0 = {
	.name=			"<init>",
	.signature=		"(Lsoot/jimple/parser/node/Token;Ljava/lang/String;)V",
	.class=			&_jc_soot_jimple_parser_parser_ParserException$type,
	.param_types=		&_jc_soot_jimple_parser_parser_ParserException$param_types$_init$97df421f1d5b7fa0,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_jimple_parser_parser_ParserException$param_ptypes$_init$97df421f1d5b7fa0,
	.signature_hash=	_JC_JLONG(0x97df421f1d5b7fa0),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_parser_parser_ParserException$method$_init$97df421f1d5b7fa0,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_soot_jimple_parser_parser_ParserException$linenum_table$_init$97df421f1d5b7fa0
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_parser_parser_ParserException, _init$97df421f1d5b7fa0);

void
_jc_soot_jimple_parser_parser_ParserException$method$_init$97df421f1d5b7fa0(_jc_env *const env, _jc_soot_jimple_parser_parser_ParserException$object *this, _jc_soot_jimple_parser_node_Token$object *param0, _jc_java_lang_String$object *param1)
{
	struct _jc_soot_jimple_parser_parser_ParserException$object *r0;
	struct _jc_soot_jimple_parser_node_Token$object *r1;
	struct _jc_java_lang_String$object *r2;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_REF_FIELD(env, r0, java_lang_Throwable, cause) = r0;
	_JC_INVOKE_VIRTUAL(env, java_lang_Throwable, fillInStackTrace$6204b72985f9038d, r0);
	_JC_REF_FIELD(env, r0, java_lang_Throwable, detailMessage) = r2;
	_JC_LINE_NUMBER(14);				// 0
	_JC_REF_FIELD(env, r0, soot_jimple_parser_parser_ParserException, token) = r1;
	_JC_LINE_NUMBER(15);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public soot.jimple.parser.node.Token getToken()
//

static _jc_linenum _jc_soot_jimple_parser_parser_ParserException$linenum_table$getToken$275e9105cf95ab28[];

static const unsigned char _jc_soot_jimple_parser_parser_ParserException$param_ptypes$getToken$275e9105cf95ab28[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_jimple_parser_parser_ParserException$method_info$getToken$275e9105cf95ab28 = {
	.name=			"getToken",
	.signature=		"()Lsoot/jimple/parser/node/Token;",
	.class=			&_jc_soot_jimple_parser_parser_ParserException$type,
	.return_type=		&_jc_soot_jimple_parser_node_Token$type,
	.param_ptypes=		&_jc_soot_jimple_parser_parser_ParserException$param_ptypes$getToken$275e9105cf95ab28,
	.signature_hash=	_JC_JLONG(0x275e9105cf95ab28),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_parser_parser_ParserException$method$getToken$275e9105cf95ab28,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_jimple_parser_parser_ParserException$vtable, soot_jimple_parser_parser_ParserException.getToken$275e9105cf95ab28) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_parser_parser_ParserException$linenum_table$getToken$275e9105cf95ab28
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_parser_parser_ParserException, getToken$275e9105cf95ab28);

_jc_soot_jimple_parser_node_Token$object *
_jc_soot_jimple_parser_parser_ParserException$method$getToken$275e9105cf95ab28(_jc_env *const env, _jc_soot_jimple_parser_parser_ParserException$object *this)
{
	struct _jc_soot_jimple_parser_parser_ParserException$object *r0;
	struct _jc_soot_jimple_parser_node_Token$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(19);				// 0
	r1 = _JC_REF_FIELD(env, r0, soot_jimple_parser_parser_ParserException, token);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_jimple_parser_parser_ParserException$methods[] = {
	&_jc_soot_jimple_parser_parser_ParserException$method_info$_init$97df421f1d5b7fa0,
	&_jc_soot_jimple_parser_parser_ParserException$method_info$getToken$275e9105cf95ab28
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_30[] = {
	&_jc_java_lang_Throwable$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_49[] = {
	&_jc_soot_jimple_parser_parser_ParserException$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_87[] = {
	&_jc_java_lang_Exception$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_jimple_parser_parser_ParserException$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[30]=	_jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_30,
	[49]=	_jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_49,
	[65]=	_jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_65,
	[87]=	_jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_87,
	[113]=	_jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_jimple_parser_parser_ParserException$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Exception",	_JC_JLONG(0xc5feb325780a6cd7) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "soot/jimple/parser/node/Token",	_JC_JLONG(0x84249dd9d0b5395d) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_jimple_parser_parser_ParserException$vtype _jc_soot_jimple_parser_parser_ParserException$type = {
    .type= {
	.name=			"soot/jimple/parser/parser/ParserException",
	.superclass=		&_jc_java_lang_Exception$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		25,
		.hash=			_JC_JLONG(0x350479636530ccb1),
		.source_file=		"ParserException.java",
		.instance_size=		sizeof(_jc_soot_jimple_parser_parser_ParserException$refs) + sizeof(_jc_soot_jimple_parser_parser_ParserException$object),
		.num_virtual_refs=	5,
		.num_fields=		sizeof(_jc_soot_jimple_parser_parser_ParserException$fields) / sizeof(*_jc_soot_jimple_parser_parser_ParserException$fields),
		.fields=		_jc_soot_jimple_parser_parser_ParserException$fields,
		.num_methods=		sizeof(_jc_soot_jimple_parser_parser_ParserException$methods) / sizeof(*_jc_soot_jimple_parser_parser_ParserException$methods),
		.methods=		_jc_soot_jimple_parser_parser_ParserException$methods,
		.instanceof_hash_table=	_jc_soot_jimple_parser_parser_ParserException$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_jimple_parser_parser_ParserException$class_depends) / sizeof(*_jc_soot_jimple_parser_parser_ParserException$class_depends),
		.class_depends=		_jc_soot_jimple_parser_parser_ParserException$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_java_lang_Throwable$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_lang_Throwable= {
	    .fillInStackTrace$6204b72985f9038d=
		&_jc_java_lang_Throwable$method$fillInStackTrace$6204b72985f9038d,
	    .getCause$d5a96efc8523817a=
		&_jc_java_lang_Throwable$method$getCause$d5a96efc8523817a,
	    .getLocalizedMessage$4c1bbba797dccd82=
		&_jc_java_lang_Throwable$method$getLocalizedMessage$4c1bbba797dccd82,
	    .getMessage$13aaf240efc902b1=
		&_jc_java_lang_Throwable$method$getMessage$13aaf240efc902b1,
	    .getStackTrace$566cca4f1a0317f8=
		&_jc_java_lang_Throwable$method$getStackTrace$566cca4f1a0317f8,
	    .initCause$997fed19751e1c64=
		&_jc_java_lang_Throwable$method$initCause$997fed19751e1c64,
	    .printStackTrace$0c533e6284fdc6db=
		&_jc_java_lang_Throwable$method$printStackTrace$0c533e6284fdc6db,
	    .printStackTrace$0235c4ad6dac60e9=
		&_jc_java_lang_Throwable$method$printStackTrace$0235c4ad6dac60e9,
	    .printStackTrace$a53e2b4b86a79644=
		&_jc_java_lang_Throwable$method$printStackTrace$a53e2b4b86a79644,
	    .setStackTrace$a5e8dbdcebe058e2=
		&_jc_java_lang_Throwable$method$setStackTrace$a5e8dbdcebe058e2,
	    .stackTraceString$42eec01c019ee6b0=
		&_jc_java_lang_Throwable$method$stackTraceString$42eec01c019ee6b0,
	    .this$adc93fb6bf4cbffa=
		&_jc_java_lang_Throwable$method$this$adc93fb6bf4cbffa,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Throwable$method$toString$7ea43b33b80a3070,
	},
	.java_lang_Exception= {
	},
	.soot_jimple_parser_parser_ParserException= {
	    .getToken$275e9105cf95ab28=
		&_jc_soot_jimple_parser_parser_ParserException$method$getToken$275e9105cf95ab28,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/jimple/parser/parser/ParserException.c <==
// public class soot.jimple.parser.parser.ParserException

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 84249dd9d0b5395d soot_jimple_parser_node_Token
// @dep_class 350479636530ccb1 soot_jimple_parser_parser_ParserException

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_jimple_parser_node_Token
// @dep_header soot_jimple_parser_parser_ParserException

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/jimple/parser/node/Token.h"
#include "soot/jimple/parser/parser/ParserException.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// soot.jimple.parser.node.Token token
static _jc_field _jc_soot_jimple_parser_parser_ParserException$field_info$token = {
	.name=		"token",
	.signature=	"Lsoot/jimple/parser/node/Token;",
	.class=		&_jc_soot_jimple_parser_parser_ParserException$type,
	.type=		&_jc_soot_jimple_parser_node_Token$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_soot_jimple_parser_parser_ParserException$object, refs[-1].soot_jimple_parser_parser_ParserException.token),
};

// Fields
static _jc_field *const _jc_soot_jimple_parser_parser_ParserException$fields[] = {
	&_jc_soot_jimple_parser_parser_ParserException$field_info$token
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(soot.jimple.parser.node.Token, java.lang.String)
//

static _jc_linenum _jc_soot_jimple_parser_parser_ParserException$linenum_table$_init$97df421f1d5b7fa0[];

static const unsigned char _jc_soot_jimple_parser_parser_ParserException$param_ptypes$_init$97df421f1d5b7fa0[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_soot_jimple_parser_parser_ParserException$param_types$_init$97df421f1d5b7fa0[] = {
	&_jc_soot_jimple_parser_node_Token$type,
	&_jc_java_lang_String$type
};

_jc_method _jc_soot_jimple_parser_parser_ParserException$method_info$_init$97df421f1d5b7fa0 = {
	.name=			"<init>",
	.signature=		"(Lsoot/jimple/parser/node/Token;Ljava/lang/String;)V",
	.class=			&_jc_soot_jimple_parser_parser_ParserException$type,
	.param_types=		&_jc_soot_jimple_parser_parser_ParserException$param_types$_init$97df421f1d5b7fa0,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_jimple_parser_parser_ParserException$param_ptypes$_init$97df421f1d5b7fa0,
	.signature_hash=	_JC_JLONG(0x97df421f1d5b7fa0),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_parser_parser_ParserException$method$_init$97df421f1d5b7fa0,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_soot_jimple_parser_parser_ParserException$linenum_table$_init$97df421f1d5b7fa0
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_parser_parser_ParserException, _init$97df421f1d5b7fa0);

void _JC_JCNI_ATTR
_jc_soot_jimple_parser_parser_ParserException$method$_init$97df421f1d5b7fa0(_jc_env *const env, _jc_soot_jimple_parser_parser_ParserException$object *this, _jc_soot_jimple_parser_node_Token$object *param0, _jc_java_lang_String$object *param1)
{
	struct _jc_soot_jimple_parser_parser_ParserException$object *r0;
	struct _jc_soot_jimple_parser_node_Token$object *r1;
	struct _jc_java_lang_String$object *r2;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_REF_FIELD(env, r0, java_lang_Throwable, cause) = r0;
	_JC_INVOKE_VIRTUAL(env, java_lang_Throwable, fillInStackTrace$6204b72985f9038d, r0);
	_JC_REF_FIELD(env, r0, java_lang_Throwable, detailMessage) = r2;
	_JC_LINE_NUMBER(14);				// 0
	_JC_REF_FIELD(env, r0, soot_jimple_parser_parser_ParserException, token) = r1;
	_JC_LINE_NUMBER(15);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public soot.jimple.parser.node.Token getToken()
//

static _jc_linenum _jc_soot_jimple_parser_parser_ParserException$linenum_table$getToken$275e9105cf95ab28[];

static const unsigned char _jc_soot_jimple_parser_parser_ParserException$param_ptypes$getToken$275e9105cf95ab28[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_jimple_parser_parser_ParserException$method_info$getToken$275e9105cf95ab28 = {
	.name=			"getToken",
	.signature=		"()Lsoot/jimple/parser/node/Token;",
	.class=			&_jc_soot_jimple_parser_parser_ParserException$type,
	.return_type=		&_jc_soot_jimple_parser_node_Token$type,
	.param_ptypes=		&_jc_soot_jimple_parser_parser_ParserException$param_ptypes$getToken$275e9105cf95ab28,
	.signature_hash=	_JC_JLONG(0x275e9105cf95ab28),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_parser_parser_ParserException$method$getToken$275e9105cf95ab28,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_jimple_parser_parser_ParserException$vtable, soot_jimple_parser_parser_ParserException.getToken$275e9105cf95ab28) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_parser_parser_ParserException$linenum_table$getToken$275e9105cf95ab28
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_parser_parser_ParserException, getToken$275e9105cf95ab28);

_jc_soot_jimple_parser_node_Token$object * _JC_JCNI_ATTR
_jc_soot_jimple_parser_parser_ParserException$method$getToken$275e9105cf95ab28(_jc_env *const env, _jc_soot_jimple_parser_parser_ParserException$object *this)
{
	struct _jc_soot_jimple_parser_parser_ParserException$object *r0;
	struct _jc_soot_jimple_parser_node_Token$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(19);				// 0
	r1 = _JC_REF_FIELD(env, r0, soot_jimple_parser_parser_ParserException, token);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_jimple_parser_parser_ParserException$methods[] = {
	&_jc_soot_jimple_parser_parser_ParserException$method_info$_init$97df421f1d5b7fa0,
	&_jc_soot_jimple_parser_parser_ParserException$method_info$getToken$275e9105cf95ab28
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_30[] = {
	&_jc_java_lang_Throwable$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_49[] = {
	&_jc_soot_jimple_parser_parser_ParserException$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_87[] = {
	&_jc_java_lang_Exception$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_jimple_parser_parser_ParserException$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[30]=	_jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_30,
	[49]=	_jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_49,
	[65]=	_jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_65,
	[87]=	_jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_87,
	[101]=	_jc_soot_jimple_parser_parser_ParserException$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_jimple_parser_parser_ParserException$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Exception",	_JC_JLONG(0xc5feb325780a6cd7) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "soot/jimple/parser/node/Token",	_JC_JLONG(0x84249dd9d0b5395d) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_jimple_parser_parser_ParserException$vtype _jc_soot_jimple_parser_parser_ParserException$type = {
    .type= {
	.name=			"soot/jimple/parser/parser/ParserException",
	.superclass=		&_jc_java_lang_Exception$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		25,
		.hash=			_JC_JLONG(0x350479636530ccb1),
		.source_file=		"ParserException.java",
		.instance_size=		sizeof(_jc_soot_jimple_parser_parser_ParserException$refs) + sizeof(_jc_soot_jimple_parser_parser_ParserException$object),
		.num_virtual_refs=	5,
		.num_fields=		sizeof(_jc_soot_jimple_parser_parser_ParserException$fields) / sizeof(*_jc_soot_jimple_parser_parser_ParserException$fields),
		.fields=		_jc_soot_jimple_parser_parser_ParserException$fields,
		.num_methods=		sizeof(_jc_soot_jimple_parser_parser_ParserException$methods) / sizeof(*_jc_soot_jimple_parser_parser_ParserException$methods),
		.methods=		_jc_soot_jimple_parser_parser_ParserException$methods,
		.instanceof_hash_table=	_jc_soot_jimple_parser_parser_ParserException$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_jimple_parser_parser_ParserException$class_depends) / sizeof(*_jc_soot_jimple_parser_parser_ParserException$class_depends),
		.class_depends=		_jc_soot_jimple_parser_parser_ParserException$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_java_lang_Throwable$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_lang_Throwable= {
	    .fillInStackTrace$6204b72985f9038d=
		&_jc_java_lang_Throwable$method$fillInStackTrace$6204b72985f9038d,
	    .getCause$d5a96efc8523817a=
		&_jc_java_lang_Throwable$method$getCause$d5a96efc8523817a,
	    .getLocalizedMessage$4c1bbba797dccd82=
		&_jc_java_lang_Throwable$method$getLocalizedMessage$4c1bbba797dccd82,
	    .getMessage$13aaf240efc902b1=
		&_jc_java_lang_Throwable$method$getMessage$13aaf240efc902b1,
	    .getStackTrace$566cca4f1a0317f8=
		&_jc_java_lang_Throwable$method$getStackTrace$566cca4f1a0317f8,
	    .initCause$997fed19751e1c64=
		&_jc_java_lang_Throwable$method$initCause$997fed19751e1c64,
	    .printStackTrace$0c533e6284fdc6db=
		&_jc_java_lang_Throwable$method$printStackTrace$0c533e6284fdc6db,
	    .printStackTrace$0235c4ad6dac60e9=
		&_jc_java_lang_Throwable$method$printStackTrace$0235c4ad6dac60e9,
	    .printStackTrace$a53e2b4b86a79644=
		&_jc_java_lang_Throwable$method$printStackTrace$a53e2b4b86a79644,
	    .setStackTrace$a5e8dbdcebe058e2=
		&_jc_java_lang_Throwable$method$setStackTrace$a5e8dbdcebe058e2,
	    .stackTraceString$42eec01c019ee6b0=
		&_jc_java_lang_Throwable$method$stackTraceString$42eec01c019ee6b0,
	    .this$adc93fb6bf4cbffa=
		&_jc_java_lang_Throwable$method$this$adc93fb6bf4cbffa,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Throwable$method$toString$7ea43b33b80a3070,
	},
	.java_lang_Exception= {
	},
	.soot_jimple_parser_parser_ParserException= {
	    .getToken$275e9105cf95ab28=
		&_jc_soot_jimple_parser_parser_ParserException$method$getToken$275e9105cf95ab28,
	},
    }
};
